==> haskell-checkers-0.5.6-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 checkers
version:              0.5.6
visibility:           public
id:                   checkers-0.5.6-EPSC7iMwiYwLo6A6g2BA3u
key:                  checkers-0.5.6-EPSC7iMwiYwLo6A6g2BA3u
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/conal/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  23d912f9b5e50f0809fb598e2b16e1d9
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-8.10.3/site-local/checkers-0.5.6
library-dirs:         /usr/lib/ghc-8.10.3/site-local/checkers-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/checkers-0.5.6
hs-libraries:         HScheckers-0.5.6-EPSC7iMwiYwLo6A6g2BA3u
depends:
    QuickCheck-2.14.2-BmAJ75208PF3IQBMR1gIGq array-0.5.4.0
    base-4.14.1.0 random-1.2.0-GQ91GOkO21I1F4AUb9ijR1
    semigroupoids-5.3.5-TUHEuvNPIbDvjWzovoeow

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.5.6-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 checkers
version:              0.5.6
visibility:           public
id:                   checkers-0.5.6-LxNgPTjWpNG8iE3HIddmvi
key:                  checkers-0.5.6-LxNgPTjWpNG8iE3HIddmvi
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/conal/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  15a6e0b524bf669029ef9eb7474c76cf
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-8.10.3/site-local/checkers-0.5.6
library-dirs:         /usr/lib/ghc-8.10.3/site-local/checkers-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/checkers-0.5.6
hs-libraries:         HScheckers-0.5.6-LxNgPTjWpNG8iE3HIddmvi
depends:
    QuickCheck-2.14.2-BJR2Lu5rIsECaJpqau9jTC array-0.5.4.0
    base-4.14.1.0 random-1.2.0-30OhcoBMr9kCHjpVnmjVCw
    semigroupoids-5.3.5-BDoIYbsvfnW3ITLacKsZX5

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
